@@ -29,35 +29,50 @@ clara.wrap <- function(data.cls, clust.num=0)
 
 agnes.clust <- function(data, clust.num=0, method="empty", ... )
 {
+#cat("\nagnes.clust")
 	return( agnes(data, method=method, ... ) )
 }
 
 diana.clust <- function(data, clust.num=0, method="empty", ... )
 {
+#cat("\ndiana.clust")
 	return( diana(data, ... ) )
 }
 
 mona.clust <- function(data, clust.num=0, method="empty", ... )
 {
+#cat("\nmona.clust")
 	return( mona(data, ... ) )
 }
 
 hclust.clust <- function(data, clust.num=0, method="empty", ... )
 {
+#cat("\nhclust.clust")
 	return( hclust( dist(data), method=method, ... ) )
 }
 
 kmeans.clust <- function(data, clust.num=0, method="empty", ... )
 {
+#cat("\nkmeans.clust")
 	return( kmeans(data, centers=clust.num, ... ) )
 }
 
 pam.clust <- function(data, clust.num=0, method="empty", ... )
 {
+#cat("\npam.clust")
 	return( pam(data, clust.num, cluster.only = TRUE,  ... ) )
 }
 
 clara.clust <- function(data, clust.num=0, method="empty", ... )
 {
+#cat("\nclara.clust")
 	return( clara(data, clust.num, ... ) )
 }
+
+# classification wrappers
+
+knn.pred <- function( base.data, base.class, rest.data )
+{
+#cat("\nknn.pred")
+	return( as.integer( knn(base.data, rest.data, base.class) ) )
+}
\ No newline at end of file
